==> 0.0.2.tar.gz: lib/src/api/get_tasks.dart <==
import 'dart:convert';

import 'package:microsoft_graph/src/core/http_client.dart';
import 'package:microsoft_graph/src/core/http_method.dart';
import 'package:microsoft_graph/src/core/http_request_message.dart';
import 'package:microsoft_graph/src/models/folder_id.dart';
import 'package:microsoft_graph/src/models/outlook_task.dart';

Stream<List<OutlookTask>> getTasks(IHttpClient httpClient, FolderId folderId) async* {
  var pageUrl;
  if (folderId is WellKnownFolderId) {
    pageUrl = "https://graph.microsoft.com/beta/me/outlook/${folderId.name}";
  } else if (folderId is SpecificFolderId) {
    pageUrl = "https://graph.microsoft.com/beta/me/outlook/taskFolders/${folderId.id}/tasks";
  } else {
    throw Exception("Unknown folderId: $folderId");
  }

  while (true) {
    final request = HttpRequestMessage(HttpMethod.Get, Uri.parse(pageUrl), []);
    final authenticatedRequest = await httpClient.authenticationProvider.authenticateRequest(request);
    final response = await httpClient.httpProvider.send(authenticatedRequest);

    Map<String, dynamic> json = jsonDecode(response.body);
    List<OutlookTask> tasks = new List();
    for (int i = 0; i < json["value"].length; i++) {
      var task = OutlookTask(
        json["value"][i]["id"],
        json["value"][i]["subject"] ?? "",
        json["value"][i]["importance"] ?? "",
        json["value"][i]["status"] ?? "",
        _parseDateTime(json["value"][i]["dueDateTime"]),
        _parseDateTime(json["value"][i]["reminderDateTime"]),
        _parseDateTime(json["value"][i]["startDateTime"]),
      );
      tasks.add(task);
    }
    yield tasks;
    if (json["@odata.nextLink"] == null) {
      return;
    } else {
      pageUrl = json["@odata.nextLink"];
    }
  }
}

DateTime _parseDateTime(Map<String, dynamic> dateMap) {
  if (dateMap != null) {
    final String dateTime = dateMap["dateTime"];
    return DateTime.parse(dateTime.split(".")[0]);
  } else {
    return null;
  }
}

==> 0.0.3.tar.gz: lib/src/api/get_tasks.dart <==
import 'dart:convert';

import 'package:microsoft_graph/src/core/http_client.dart';
import 'package:microsoft_graph/src/core/http_method.dart';
import 'package:microsoft_graph/src/core/http_request_message.dart';
import 'package:microsoft_graph/src/models/folder_id.dart';
import 'package:microsoft_graph/src/models/outlook_task.dart';

Stream<List<OutlookTask>> getTasks(IHttpClient httpClient, FolderId folderId) async* {
  var pageUrl;
  if (folderId is WellKnownFolderId) {
    pageUrl = "https://graph.microsoft.com/beta/me/outlook/${folderId.name}";
  } else if (folderId is SpecificFolderId) {
    pageUrl = "https://graph.microsoft.com/beta/me/outlook/taskFolders/${folderId.id}/tasks";
  } else {
    throw Exception("Unknown folderId: $folderId");
  }

  while (true) {
    final request = HttpRequestMessage(HttpMethod.Get, Uri.parse(pageUrl), []);
    final authenticatedRequest = await httpClient.authenticationProvider.authenticateRequest(request);
    final response = await httpClient.httpProvider.send(authenticatedRequest);

    Map<String, dynamic> json = jsonDecode(response.body);
    List<OutlookTask> tasks = new List();
    for (int i = 0; i < json["value"].length; i++) {
      var task = OutlookTask(
        id: json["value"][i]["id"],
        subject: json["value"][i]["subject"] ?? "",
        importance: json["value"][i]["importance"] ?? "",
        status: json["value"][i]["status"] ?? "",
        dueDateTime: _parseDateTime(json["value"][i]["dueDateTime"]),
        reminderDateTime: _parseDateTime(json["value"][i]["reminderDateTime"]),
        startDateTime: _parseDateTime(json["value"][i]["startDateTime"]),
      );
      tasks.add(task);
    }
    yield tasks;
    if (json["@odata.nextLink"] == null) {
      return;
    } else {
      pageUrl = json["@odata.nextLink"];
    }
  }
}

DateTime _parseDateTime(Map<String, dynamic> dateMap) {
  if (dateMap != null) {
    final String dateTime = dateMap["dateTime"];
    return DateTime.parse(dateTime.split(".")[0]);
  } else {
    return null;
  }
}
